@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2012 IBM Corporation and others.
+ * Copyright (c) 2000, 2014 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -156,6 +156,9 @@ public class SearchableEnvironment implements INameEnvironment,
 					else if (sourceType.getHandle().getClassFile()!=null)
 						 types = sourceType.getHandle().getClassFile().getTypes();
 
+					if (types == null || types.length == 0)
+						return null;
+					
 					ISourceType[] sourceTypes = new ISourceType[types.length];
 
 					// in the resulting collection, ensure the requested type is
