@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2011 IBM Corporation and others All rights reserved. This
+ * Copyright (c) 2009, 2012 IBM Corporation and others All rights reserved. This
  * program and the accompanying materials are made available under the terms of
  * the Eclipse Public License v1.0 which accompanies this distribution, and is
  * available at http://www.eclipse.org/legal/epl-v10.html
@@ -157,7 +157,7 @@ public class RhinoDebuggerImpl implements Debugger, ContextFactory.Listener {
 			}
 			else {
 				//a totally new script is loaded
-				id = scriptId();
+				id = new Long(currentScriptId++);
 				newscript.setId(id);
 			}
 			uriToScript.put(uri, newscript);
@@ -237,15 +237,6 @@ public class RhinoDebuggerImpl implements Debugger, ContextFactory.Listener {
 		return null;
 	}
 	
-	/**
-	 * Returns the next script id to use
-	 * 
-	 * @return the next id
-	 */
-	synchronized Long scriptId() {
-		return new Long(currentScriptId++);
-	}
-	
 	/*
 	 * (non-Javadoc)
 	 * 
