@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2009 IBM Corporation and others.
+ * Copyright (c) 2000, 2013 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -204,7 +204,7 @@ public class JavadocTagsSubProcessor {
 		 	}
 		 	if (!methodDecl.isConstructor()) {
 		 		Type type= methodDecl.getReturnType2();
-		 		if (!type.isPrimitiveType() || (((PrimitiveType) type).getPrimitiveTypeCode() != PrimitiveType.VOID)) {
+		 		if (type != null && (!type.isPrimitiveType() || (((PrimitiveType) type).getPrimitiveTypeCode() != PrimitiveType.VOID))) {
 		 			if (findTag(javadoc, TagElement.TAG_RETURN, null) == null) {
 		 				TagElement newTag= ast.newTagElement();
 		 				newTag.setTagName(TagElement.TAG_RETURN);
