@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2003, 2013 IBM Corporation and others.
+ * Copyright (c) 2003, 2014 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -55,7 +55,9 @@ import org.eclipse.swt.widgets.Spinner;
 import org.eclipse.swt.widgets.Table;
 import org.eclipse.swt.widgets.Text;
 import org.eclipse.ui.IEditorInput;
+import org.eclipse.ui.IEditorPart;
 import org.eclipse.ui.IEditorSite;
+import org.eclipse.ui.IWorkbenchPage;
 import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.dialogs.ContainerSelectionDialog;
 import org.eclipse.ui.forms.IFormColors;
@@ -65,6 +67,7 @@ import org.eclipse.ui.forms.events.HyperlinkAdapter;
 import org.eclipse.ui.forms.events.HyperlinkEvent;
 import org.eclipse.ui.forms.widgets.*;
 import org.eclipse.ui.help.IWorkbenchHelpSystem;
+import org.eclipse.ui.part.MultiPageEditorSite;
 import org.eclipse.wst.server.core.*;
 import org.eclipse.wst.server.core.internal.Publisher;
 import org.eclipse.wst.server.core.internal.Server;
@@ -107,6 +110,7 @@ public class OverviewEditorPart extends ServerEditorPart implements IUIControlLi
 	protected Spinner startTimeoutSpinner;
 	protected Spinner stopTimeoutSpinner;
 	protected ManagedForm managedForm;
+	private List<ServerEditorOverviewPageModifier> pageModifiersList;
 
 	protected boolean updating;
 
@@ -315,10 +319,11 @@ public class OverviewEditorPart extends ServerEditorPart implements IUIControlLi
 		
 		initialize();
 		
-		if (serverName != null)
+		if (serverName != null){
 			serverName.setFocus();
+		}
 		else if (serverConfiguration != null)
-			serverConfiguration.setFocus();		
+			serverConfiguration.setFocus();			
 	}
 
 	protected void createGeneralSection(Composite leftColumnComp, FormToolkit toolkit) {
@@ -410,9 +415,10 @@ public class OverviewEditorPart extends ServerEditorPart implements IUIControlLi
 		// runtime
 		if (server != null && server.getServerType() != null && server.getServerType().hasRuntime()) {
 			final Hyperlink link = toolkit.createHyperlink(composite, Messages.serverEditorOverviewRuntime, SWT.NONE);
+			final IServerWorkingCopy server2 = server;
 			link.addHyperlinkListener(new HyperlinkAdapter() {
 				public void linkActivated(HyperlinkEvent e) {
-					IRuntime runtime = server.getRuntime();
+					IRuntime runtime = server2.getRuntime();
 					if (runtime != null && ServerUIPlugin.hasWizardFragment(runtime.getRuntimeType().getId()))
 						editRuntime(runtime);
 				}
@@ -446,7 +452,7 @@ public class OverviewEditorPart extends ServerEditorPart implements IUIControlLi
 						updating = true;
 						IRuntime newRuntime = runtimes[runtimeCombo.getSelectionIndex()];
 						execute(new SetServerRuntimeCommand(getServer(), newRuntime));
-						link.setEnabled(newRuntime != null && !ServerUIPlugin.hasWizardFragment(newRuntime.getRuntimeType().getId()));
+						link.setEnabled(newRuntime != null && ServerUIPlugin.hasWizardFragment(newRuntime.getRuntimeType().getId()));
 						updating = false;
 					} catch (Exception ex) {
 						// ignore
@@ -575,18 +581,22 @@ public class OverviewEditorPart extends ServerEditorPart implements IUIControlLi
 			browse.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_END));
 		}
 		
+		IServerType serverType = null;
 		if (server != null && server.getServerType() != null) {
-			IServerType serverType = server.getServerType();
+			serverType = server.getServerType();
 			if (serverType.supportsLaunchMode(ILaunchManager.RUN_MODE) || serverType.supportsLaunchMode(ILaunchManager.DEBUG_MODE)
 					|| serverType.supportsLaunchMode(ILaunchManager.PROFILE_MODE)) {
 				ILaunchConfigurationType launchType = ((ServerType) serverType).getLaunchConfigurationType();
 				if (launchType != null && launchType.isPublic()) {
 					final Hyperlink link = toolkit.createHyperlink(composite, Messages.serverEditorOverviewOpenLaunchConfiguration, SWT.NONE);
 					GridData data = new GridData();
-					data.horizontalSpan = 2;
+					data.horizontalSpan = 3;
 					link.setLayoutData(data);
 					link.addHyperlinkListener(new HyperlinkAdapter() {
 						public void linkActivated(HyperlinkEvent e) {
+							IEditorPart part = ((MultiPageEditorSite)getSite()).getMultiPageEditor();
+							IWorkbenchPage page = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage();
+							page.saveEditor(part, true);
 							try {
 								ILaunchConfiguration launchConfig = ((Server) getServer()).getLaunchConfiguration(true, null);
 								// TODO: use correct launch group
@@ -604,9 +614,12 @@ public class OverviewEditorPart extends ServerEditorPart implements IUIControlLi
 		
 		// Insertion of extension widgets. If the page modifier createControl is not implemented still 
 		// add the modifier to the listeners list.
-		List<ServerEditorOverviewPageModifier> pageModifiersLst = ServerUIPlugin.getServerEditorOverviewPageModifiers();
+		List<ServerEditorOverviewPageModifier> pageModifiersLst = getPageModifiers(serverType == null ? null : serverType.getId());
 		for (ServerEditorOverviewPageModifier curPageModifier : pageModifiersLst) {
 			if(server != null && server.getServerType() != null){
+				curPageModifier.setServerWorkingCopy(server);
+				curPageModifier.setServerEditorPart(this);
+				curPageModifier.setFormToolkit(toolkit);
 				curPageModifier.createControl(ServerEditorOverviewPageModifier.UI_LOCATION.OVERVIEW, composite);
 				curPageModifier.setUIControlListener(this);
 			}
@@ -1015,7 +1028,7 @@ public class OverviewEditorPart extends ServerEditorPart implements IUIControlLi
 				autoPublishTime.setEnabled(publishSetting != Server.AUTO_PUBLISH_DISABLE);
 			}
 			
-			List<ServerEditorOverviewPageModifier> pageModifiersLst = ServerUIPlugin.getServerEditorOverviewPageModifiers();
+			List<ServerEditorOverviewPageModifier> pageModifiersLst = getPageModifiers(null);
 			for (ServerEditorOverviewPageModifier curPageModifier : pageModifiersLst) {
 				if(server != null && server.getServerType() != null)
 					curPageModifier.setServerWorkingCopy(server);
@@ -1026,6 +1039,14 @@ public class OverviewEditorPart extends ServerEditorPart implements IUIControlLi
 		updating = false;
 		validate();
 	}
+	
+	private List<ServerEditorOverviewPageModifier> getPageModifiers(String serverTypeId) {
+		if( pageModifiersList == null )  {
+			pageModifiersList = ServerUIPlugin.getServerEditorOverviewPageModifiers(serverTypeId);
+		}
+
+		return pageModifiersList;
+	}
 
 	protected void validate() {
 		IManagedForm mForm = getManagedForm();
@@ -1091,7 +1112,7 @@ public class OverviewEditorPart extends ServerEditorPart implements IUIControlLi
 		// Previously, it was going to the server name text field instead of the
 		// selected control in the editor when the focus was given to the 
 		// server editor (e.g. clicking something outside the server editor and 
-		// then clicking a control in the server editor) 
+		// then clicking a control in the server editor)
 	}
 
 	public String getControlStringValue(String controlId) {
