@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2011 IBM Corporation and others.
+ * Copyright (c) 2009, 2014 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -298,6 +298,8 @@ public class SemanticHighlightingManager implements IPropertyChangeListener {
 	private static final String TARGET_ATTR = "target"; //$NON-NLS-1$
 	private static final String CLASS_ATTR = "class"; //$NON-NLS-1$
 	private static final String STYLE_KEY_ATTR = "styleStringKey"; //$NON-NLS-1$
+	private static final String ID_ATTR = "id"; //$NON-NLS-1$
+	private static final String AFTER_ATTR = "after"; //$NON-NLS-1$
 
 	private ISourceViewer fSourceViewer;
 	private IPreferenceStore fPreferenceStore;
@@ -348,6 +350,8 @@ public class SemanticHighlightingManager implements IPropertyChangeListener {
 		
 		ISemanticHighlighting highlighting = null;
 		String styleKey = null;
+		String id = null;
+		String after = null;
 		IConfigurationElement[] elements = Platform.getExtensionRegistry().getConfigurationElementsFor(SSEUIPlugin.ID, SEMANTIC_HIGHLIGHTING_EXTENSION_POINT);
 		
 		IContentType contentType = Platform.getContentTypeManager().getContentType(fContentTypeId);
@@ -361,11 +365,15 @@ public class SemanticHighlightingManager implements IPropertyChangeListener {
 					try {
 						highlighting = (ISemanticHighlighting) elements[i].createExecutableExtension(CLASS_ATTR);
 						styleKey = elements[i].getAttribute(STYLE_KEY_ATTR);
+						id = elements[i].getAttribute(ID_ATTR);
+						after = elements[i].getAttribute(AFTER_ATTR);
 					} catch (CoreException e) {
 						Logger.logException(e);
 					}
-					if (highlighting != null)
-						semantics.add(new SemanticContent(targetContentType, highlighting, styleKey));
+					if (highlighting != null) {
+						// The highlighting was not inserted through priority; insert at the beginning of the list
+						semantics.add(new SemanticContent(targetContentType, highlighting, styleKey, id, after));
+					}
 
 					break;
 				}
@@ -394,18 +402,25 @@ public class SemanticHighlightingManager implements IPropertyChangeListener {
 		public IContentType type;
 		public ISemanticHighlighting highlighting;
 		public String styleKey;
-
-		public SemanticContent(IContentType type, ISemanticHighlighting highlighting, String styleKey) {
+		public String id;
+		public String after;
+		public SemanticContent(IContentType type, ISemanticHighlighting highlighting, String styleKey, String id, String after) {
 			this.type = type;
 			this.highlighting = highlighting;
 			this.styleKey = styleKey;
+			this.id = id;
+			this.after = after;
 		}
 
 		public int compareTo(Object arg0) {
 			SemanticContent other = (SemanticContent) arg0;
 			/* Equal weighting for the same types */
-			if (this.type.equals(other.type))
+			if (this.type.equals(other.type)) {
+				if (this.after != null && other.id != null && other.id.equals(this.after)) {
+					return 1;
+				}
 				return 0;
+			}
 			/* Subtypes have more weight than base types */
 			if (this.type.isKindOf(other.type))
 				return 1;
